# `autofeat` library

This library contains `sklearn`-compatible linear prediction models with automated feature engineering and selection capabilities.

For more information please have a look at the [documentation](https://franziskahorn.de/autofeat).

The code is intended for research purposes.

If you have any questions please don't hesitate to send me an [email](mailto:cod3licious@gmail.com) and of course if you should find any bugs or want to contribute other improvements, pull requests are very welcome!


### Acknowledgments

This project was made possible thanks to support by [BASF](https://www.basf.com).
